@@ -20,7 +20,6 @@ use crate::{
     storage::{Metadata, StorageBackend},
 };
 use async_trait::async_trait;
-use futures::prelude::*;
 use std::{path::PathBuf, sync::Arc};
 
 #[derive(Debug)]
@@ -46,8 +45,8 @@ where
         let mut session = args.session.lock().await;
         let storage: Arc<Storage> = Arc::clone(&session.storage);
         let path = session.cwd.join(self.path.clone());
-        let mut tx_success = args.tx_control_chan.clone();
-        let mut tx_fail = args.tx_control_chan.clone();
+        let tx_success = args.tx_control_chan.clone();
+        let tx_fail = args.tx_control_chan.clone();
         let logger = args.logger;
 
         if let Err(err) = storage.cwd((*session.user).as_ref().unwrap(), path.clone()).await {
